@@ -46,27 +46,28 @@ class prefsWidget(object):
             self.tooltips.set_tip(self.eboxes[i],prefTooltipLabels[i])
         self.tooltips.set_tip(self.jack_ebox,prefJacktip)
 
+
     def destroy(self,Event=None):
         self.values[0]=self.fpsSpinButton.get_value_as_int()
         self.values[1]=self.mouseComboBox.get_active()
-        self.values[3]=self.fullComboBox.get_active()
+        self.values[3]=int(not self.fullComboBox.get_active())
         self.values[7]=self.channelsSpinButton.get_value_as_int()
         self.values[8]=self.freqSpinButton.get_value_as_int()
         self.values[9]=self.deviceEntry.get_text().replace(' ','')
         self.values[12]=self.displayEntry.get_text().replace(' ','')
-        self.values[13]=self.sharedComboBox.get_active()
-        self.values[14]=self.areaResetComboBox.get_active()
-        self.values[15]=self.followMouseComboBox.get_active()
-        self.values[16]=self.quickComboBox.get_active()
+        self.values[13]=int(not self.sharedComboBox.get_active())
+        self.values[14]=int(not self.areaResetComboBox.get_active())
+        self.values[15]=int(not self.followMouseComboBox.get_active())
+        self.values[16]=int(not self.quickComboBox.get_active())
         self.values[17]=self.workdirEntry.get_text()
-        self.values[18]=self.onTheFlyComboBox.get_active()
-        self.values[19]=self.zeroCmpComboBox.get_active()
+        self.values[18]=int(not self.onTheFlyComboBox.get_active())
+        self.values[19]=int(not self.zeroCmpComboBox.get_active())
         self.values[20]=self.overwriteFilesButton.get_active()
-        self.values[21]=self.winDecoComboBox.get_active()
+        self.values[21]=int(not self.winDecoComboBox.get_active())
         self.values[22]=self.jack_button.get_active()
         self.__getSelectedPorts__()
-        self.values[24]=self.tooltipsComboBox.get_active()
-        self.values[25]=self.rFrameComboBox.get_active()
+        self.values[24]=int(not self.tooltipsComboBox.get_active())
+        self.values[25]=int(not self.rFrameComboBox.get_active())
         self.values[26]=self.extraOptsEntry.get_text().strip()
         self.window.destroy()
         self.optionsOpen[0]=0
@@ -86,6 +87,22 @@ class prefsWidget(object):
         for i in iters_t:
             self.values[23].append(self.jack_lsp_listview.get_model().get_value(i,0))
 
+    def __fileSelQuit__(self,Event=None):
+        self.fileSel.destroy()
+
+    def __fileSelOk__(self,Event=None):
+        new_val=self.fileSel.get_filename()
+        self.workdirEntry.set_text(new_val)
+        self.fileSel.destroy()
+
+    def __fileSelect__(self,Event=None):
+        self.fileSel = gtk.FileSelection(title=None)
+        self.fileSel.ok_button.connect("clicked", self.__fileSelOk__)
+        self.fileSel.cancel_button.connect("clicked", self.__fileSelQuit__)
+        self.fileSel.set_filename(self.workdirEntry.get_text())
+        self.fileSel.show()
+
+
     def __subWidgets__(self):
         self.labels={}
         self.boxes={}
@@ -106,6 +123,9 @@ class prefsWidget(object):
             self.eboxes[i].add(self.boxes[i])
             self.labelbox[0].pack_start(self.eboxes[i],expand=False,fill=False)
 
+        self.workdir_layout=gtk.HBox(homogeneous=False, spacing=0)
+
+
         self.overwriteFilesButton=gtk.CheckButton(label=None)
         self.overwriteFilesButton.set_active(self.values[20])
         self.overwriteFilesButton.show()
@@ -114,7 +134,19 @@ class prefsWidget(object):
         self.workdirEntry= gtk.Entry(max=0)
         self.workdirEntry.set_text(self.values[17])
         self.workdirEntry.show()
-        self.boxes[1].pack_end(self.workdirEntry,expand=True,fill=True)
+        #self.boxes[1].pack_end(self.workdirEntry,expand=False,fill=False)
+        #self.file_button=gtk.Button(None,gtk.STOCK_SAVE_AS)
+        #self.file_button.show()
+        self.workdir_button=gtk.Button(None,gtk.STOCK_SAVE_AS)
+        self.workdir_button.show()
+
+
+        self.workdir_layout.pack_start(self.workdirEntry,expand=True,fill=True)
+        self.workdir_layout.pack_start(self.workdir_button,expand=False,fill=False)
+        self.workdir_layout.show()
+
+        self.labelbox[0].pack_start(self.workdir_layout,expand=False,fill=False)
+
 
 #Performance page
         for i in xrange(2,7):
@@ -132,31 +164,23 @@ class prefsWidget(object):
         self.fpsSpinButton.show()
         self.boxes[2].pack_end(self.fpsSpinButton,expand=False,fill=False)
 
-        self.onTheFlyComboBox = gtk.combo_box_new_text()
-        for i in range(2):
-            self.onTheFlyComboBox.append_text(prefStateStrings[i])
-        self.onTheFlyComboBox.set_active(self.values[18])
+        self.onTheFlyComboBox = gtk.CheckButton(" ")
+        self.onTheFlyComboBox.set_active(int(not self.values[18]))
         self.onTheFlyComboBox.show()
         self.boxes[3].pack_end(self.onTheFlyComboBox,expand=False,fill=False)
 
-        self.zeroCmpComboBox = gtk.combo_box_new_text()
-        for i in range(2):
-            self.zeroCmpComboBox.append_text(prefStateStrings[i])
-        self.zeroCmpComboBox.set_active(self.values[19])
+        self.zeroCmpComboBox = gtk.CheckButton(" ")
+        self.zeroCmpComboBox.set_active(int(not self.values[19]))
         self.zeroCmpComboBox.show()
         self.boxes[4].pack_end(self.zeroCmpComboBox,expand=False,fill=False)
 
-        self.quickComboBox = gtk.combo_box_new_text()
-        for i in range(2):
-            self.quickComboBox.append_text(prefStateStrings[i])
-        self.quickComboBox.set_active(self.values[16])
+        self.quickComboBox = gtk.CheckButton(" ")
+        self.quickComboBox.set_active(int(not self.values[16]))
         self.quickComboBox.show()
         self.boxes[5].pack_end(self.quickComboBox,expand=False,fill=False)
 
-        self.fullComboBox = gtk.combo_box_new_text()
-        for i in range(2):
-            self.fullComboBox.append_text(prefStateStrings[i])
-        self.fullComboBox.set_active(self.values[3])
+        self.fullComboBox = gtk.CheckButton(" ")
+        self.fullComboBox.set_active(int(not self.values[3]))
         self.fullComboBox.show()
         self.boxes[6].pack_end(self.fullComboBox,expand=False,fill=False)
 
@@ -224,7 +248,7 @@ class prefsWidget(object):
         self.boxes[7].pack_end(self.channelsSpinButton,expand=False,fill=False)
 
 
-        self.freqAdjustment=gtk.Adjustment(value=self.values[8], lower=0,upper=44100, step_incr=1, page_incr=100, page_size=0)
+        self.freqAdjustment=gtk.Adjustment(value=self.values[8], lower=0,upper=48000, step_incr=1, page_incr=100, page_size=0)
         self.freqSpinButton= gtk.SpinButton(self.freqAdjustment, climb_rate=0.5, digits=0)
         self.freqSpinButton.show()
         self.boxes[8].pack_end(self.freqSpinButton,expand=False,fill=False)
@@ -259,46 +283,34 @@ class prefsWidget(object):
         self.mouseComboBox.show()
         self.boxes[11].pack_end(self.mouseComboBox,expand=False,fill=False)
 
-        self.followMouseComboBox = gtk.combo_box_new_text()
-        for i in range(2):
-            self.followMouseComboBox.append_text(prefStateStrings[i])
-        self.followMouseComboBox.set_active(self.values[15])
+        self.followMouseComboBox = gtk.CheckButton(" ")
+        self.followMouseComboBox.set_active(int(not self.values[15]))
         self.followMouseComboBox.show()
         self.boxes[12].pack_end(self.followMouseComboBox,expand=False,fill=False)
 
-        self.sharedComboBox = gtk.combo_box_new_text()
-        for i in range(2):
-            self.sharedComboBox.append_text(prefStateStrings[i])
-        self.sharedComboBox.set_active(self.values[13])
+        self.sharedComboBox = gtk.CheckButton(" ")
+        self.sharedComboBox.set_active(int(not self.values[13]))
         self.sharedComboBox.show()
         self.boxes[13].pack_end(self.sharedComboBox,expand=False,fill=False)
 
-        self.winDecoComboBox = gtk.combo_box_new_text()
-        for i in range(2):
-            self.winDecoComboBox.append_text(prefStateStrings[i])
-        self.winDecoComboBox.set_active(self.values[21])
+        self.winDecoComboBox = gtk.CheckButton(" ")
+        self.winDecoComboBox.set_active(int(not self.values[21]))
         self.winDecoComboBox.show()
         self.boxes[14].pack_end(self.winDecoComboBox,expand=False,fill=False)
 
-        self.tooltipsComboBox = gtk.combo_box_new_text()
-        for i in range(2):
-            self.tooltipsComboBox.append_text(prefStateStrings[i])
-        self.tooltipsComboBox.set_active(self.values[24])
+        self.tooltipsComboBox = gtk.CheckButton(" ")
+        self.tooltipsComboBox.set_active(int(not self.values[24]))
         self.tooltipsComboBox.show()
         self.boxes[15].pack_end(self.tooltipsComboBox,expand=False,fill=False)
 
 
-        self.rFrameComboBox = gtk.combo_box_new_text()
-        for i in range(2):
-            self.rFrameComboBox.append_text(prefStateStrings[i])
-        self.rFrameComboBox.set_active(self.values[25])
+        self.rFrameComboBox = gtk.CheckButton(" ")
+        self.rFrameComboBox.set_active(int(not self.values[25]))
         self.rFrameComboBox.show()
         self.boxes[16].pack_end(self.rFrameComboBox,expand=False,fill=False)
 
-        self.areaResetComboBox = gtk.combo_box_new_text()
-        for i in range(2):
-            self.areaResetComboBox.append_text(prefStateStrings[i])
-        self.areaResetComboBox.set_active(self.values[14])
+        self.areaResetComboBox = gtk.CheckButton(" ")
+        self.areaResetComboBox.set_active(int(not self.values[14]))
         self.areaResetComboBox.show()
         self.boxes[17].pack_end(self.areaResetComboBox,expand=False,fill=False)
 
@@ -352,9 +364,33 @@ class prefsWidget(object):
         if (not failed) and self.values[23]==[]:
             self.jack_lsp_listview.get_selection().select_path((0,))
             #print self.jack_lsp_listview.get_selection().get_selected_rows()
+
+    def __workdirSelect__(self,Event=None):
+        p=gtk.FileChooserDialog(title=None,
+                                action=gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER,
+                                buttons=(gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,
+                                         gtk.STOCK_OPEN,gtk.RESPONSE_OK)
+                               )
+        p.set_filename(self.workdirEntry.get_text())
+        if p.run()==gtk.RESPONSE_OK:
+            tpath=p.get_filename()
+            if tpath!= '':
+                self.workdirEntry.set_text(tpath)
+        p.hide()
+        p.destroy()
+
     def __makeCons__(self):
         self.jack_button.connect("clicked",self.__jack_enabled_check__)
         self.jack_lsp_refresh.connect("clicked",self.__runJackLSP__)
+        self.workdir_button.connect("clicked",self.__workdirSelect__)
+
+    def __register_shortcuts__(self):
+        self.parent.advanced_button.add_accelerator("clicked",self.accel_group,
+                                     ord('P'), gtk.gdk.CONTROL_MASK,
+                                     gtk.ACCEL_VISIBLE)
+        self.parent.advanced_button.add_accelerator("clicked",self.accel_group,
+                                     gtk.gdk.keyval_from_name("Escape"),0,
+                                     gtk.ACCEL_VISIBLE)
 
     def __jack_enabled_check__(self,widget):
         self.channelsSpinButton.set_sensitive(not widget.get_active())
@@ -363,16 +399,21 @@ class prefsWidget(object):
         self.jack_lsp_listview.set_sensitive(widget.get_active())
         self.jack_lsp_refresh.set_sensitive(widget.get_active())
 
-    def __init__(self,values,optionsOpen):
+    def __init__(self,parent,values,optionsOpen):
         self.values=values
         self.ports=[]
+        self.parent=parent
         self.optionsOpen=optionsOpen
         self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
         self.window.connect("destroy", self.destroy)
         self.window.set_border_width(10)
-        self.window.set_title("recordMyDesktop")
+        self.window.set_title("recordMyDesktop: "+smplButtonStrings[0])
+        self.accel_group = gtk.AccelGroup()
+        self.window.add_accel_group(self.accel_group)
+
         self.__subWidgets__()
         self.__makeCons__()
+        self.__register_shortcuts__()
         self.__runJackLSP__()
         self.__jack_enabled_check__(self.jack_button)
         if self.values[24]==0:
